<?php

/*
	WPB Woocommerce Product Slider pro 
	By WPBean
	
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly 


/* Settings API class */

require_once dirname( __FILE__ ) . '/class.settings-api.php';


/**
 * WPS Main settings
 */

if ( !class_exists('WPB_wps_main_Settings' ) ):
class WPB_wps_main_Settings {

    private $settings_api;

    function __construct() {
        $this->settings_api = new WPB_WPS_WeDevs_Settings_API;

        add_action( 'admin_init', array($this, 'admin_init') );
        add_action( 'admin_menu', array($this, 'admin_menu') );
    }

    function admin_init() {

        //set the settings
        $this->settings_api->set_sections( $this->get_settings_sections() );
        $this->settings_api->set_fields( $this->get_settings_fields() );

        //initialize settings
        $this->settings_api->admin_init();
    }
	
    function admin_menu() {
        add_menu_page( __( 'WPB WooCommerce Product Slider', 'wpb-woocommerce-product-slider' ), __( 'Product Slider', 'wpb-woocommerce-product-slider' ), 'delete_posts', 'wpb_woo_product_slider', array( $this, 'wpb_plugin_page' ), 'dashicons-cart' );

    }
	// setings tabs
    function get_settings_sections() {
        $sections = array(
            array(
                'id'    => 'wpb_wps_general',
                'title' => __( 'General Settings', 'wpb-woocommerce-product-slider' )
            ),
			array(
                'id'    => 'wpb_wps_style_settings',
                'title' => __( 'Style Settings', 'wpb-woocommerce-product-slider' )
            ),
            array(
                'id'    => 'wpb_wps_slider_settings',
                'title' => __( 'Slider Settings', 'wpb-woocommerce-product-slider' )
            ),
            array(
                'id'    => 'wpb_wps_advance_settings',
                'title' => __( 'Advance Settings', 'wpb-woocommerce-product-slider' )
            ),
        );
        return $sections;
    }

    /**
     * Returns all the settings fields
     *
     * @return array settings fields
     */
    function get_settings_fields() {
        $settings_fields = array( 
			
			// Theme 1 Settings
            'wpb_wps_general' => array(
                array(
                    'name'             => 'wpb_wps_product_title_limit',
                    'label'            => __( 'Product title characters limit', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'    => __( 'Enable/ disable the product title character limit.  Default Off.', 'wpb-woocommerce-product-slider' ),
                    'type'             => 'checkbox',
                    'default'          => 'off',
                ),
				array(
                    'name'      => 'wpb_title_mx_ch',
                    'label'     => __( 'Product Title max character', 'wpb-woocommerce-product-slider' ),
                    'desc'      => __( 'If you enable the title characters limit you may also want to set number of characters to show.', 'wpb-woocommerce-product-slider' ),
                    'type'      => 'number',
                    'default'   => 10
				),
                array(
                    'name'             => 'wpb_wps_show_title',
                    'label'            => __( 'Show title', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'    => __( 'Show product title or not.  Default On.', 'wpb-woocommerce-product-slider' ),
                    'type'             => 'checkbox',
                    'default'          => 'on',
                ),
				array(
					'name'             => 'wpb_wps_show_category',
					'label'            => __( 'Show Category', 'wpb-woocommerce-product-slider' ),
					'checkbox_desc'    => __( 'Show product category or not.( Only for Grid theme.) Default On.', 'wpb-woocommerce-product-slider' ),
					'type'             => 'checkbox',
					'default'          => 'on',
				),
                array(
                    'name'             => 'wpb_wps_show_price',
                    'label'            => __( 'Show Price', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'    => __( 'Show product price or not. Default On.', 'wpb-woocommerce-product-slider' ),
                    'type'             => 'checkbox',
                    'default'          => 'on',
                ),
                array(
                    'name'             => 'wpb_wps_show_reviews',
                    'label'            => __( 'Show Reviews', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'    => __( 'Show product reviews or not. Default Off.', 'wpb-woocommerce-product-slider' ),
                    'type'             => 'checkbox',
                    'default'          => 'off',
                ),
				array(
					'name'             => 'wpb_wps_show_cart',
					'label'            => __( 'Show cart', 'wpb-woocommerce-product-slider' ),
					'checkbox_desc'    => __( 'Show add to cart button or not.  Default On.', 'wpb-woocommerce-product-slider' ),
					'type'             => 'checkbox',
					'default'          => 'on',
				),
                array(
                    'name'             => 'show_availability',
                    'label'            => __( 'Show availability', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'    => __( 'Show availability( stock ) of products.  Default On.', 'wpb-woocommerce-product-slider' ),
                    'type'             => 'checkbox',
                    'default'          => 'on',
                ),
                array(
                    'name'              => 'wpb_wps_show_ribon',
                    'label'             => __( 'Show ribon', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'     => __( 'Show On Sell ribon.  Default On.', 'wpb-woocommerce-product-slider' ),
                    'type'              => 'checkbox',
                    'default'           => 'on',
                ),
                array(
                    'name'              => 'wpb_wps_show_out_of_stock',
                    'label'             => __( 'Show Out of Stock', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'     => __( 'Out of Stock products can be enable or disable form the slider. Default Off.', 'wpb-woocommerce-product-slider' ),
                    'type'              => 'checkbox',
                    'default'           => 'off',
                ),
            ),
			
			'wpb_wps_style_settings' => array(
                array(
                    'name'      => 'wpb_wps_rating_color',
                    'label'     => __( 'Product slider rating color', 'wpb-woocommerce-product-slider' ),
                    'desc'      => __( 'Product slider rating/review color.', 'wpb-woocommerce-product-slider' ),
                    'type'      => 'color',
                    'default'   => '#f7a308'
                ),
                array(
                    'name'      => 'wpb_wps_nav_pagi_color',
                    'label'     => __( 'Navigation and pagination color', 'wpb-woocommerce-product-slider' ),
                    'desc'      => __( 'Product slider navigation and pagination color.', 'wpb-woocommerce-product-slider' ),
                    'type'      => 'color',
                    'default'   => '#cccccc'
                ),
				array(
					'name'     => 'wpb_wps_custom_css',
					'label'    => __( 'Custom CSS', 'wpb-woocommerce-product-slider' ),
					'desc'     => __( 'You can write your own custom CSS, if you want.', 'wpb-woocommerce-product-slider' ),
					'type'     => 'textarea'
				),
                array(
                    'name'              => 'wpb_wps_load_font_awesome',
                    'label'             => __( 'Load Font Awesome CSS', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'     => __( 'You can disable loading Font Awesome icon css form this plugin, if your theme or any other plugin loading this. Default Yes.', 'wpb-woocommerce-product-slider' ),
                    'type'              => 'checkbox',
                    'default'           => 'on',
                ),
			),

            'wpb_wps_slider_settings' => array(
                array(
                    'name'              => 'wpb_wps_auto_crop_images',
                    'label'             => __( 'Product Image Cropping', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'     => __( 'Product image cropping. If set Yes, it will take image size form shortcode attribute and if set No, it will take image size form WooCommerce Settings.  Default Yes.', 'wpb-woocommerce-product-slider' ),
                    'type'              => 'checkbox',
                    'default'           => 'on',
                ),
                array(
                    'name'           => 'wpb_wps_mouse_drag',
                    'label'          => __( 'Slider Mouse Drag', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc'  => __( 'Turn Off/On Mouse Drag. Default Yes.', 'wpb-woocommerce-product-slider' ),
                    'type'           => 'checkbox',
                    'default'        => 'on',
                ),
                array(
                    'name'          => 'wpb_wps_touch_drag',
                    'label'         => __( 'Slider Touch Drag', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc' => __( 'Turn Off/On Touch Drag. Default Yes.', 'wpb-woocommerce-product-slider' ),
                    'type'          => 'checkbox',
                    'default'       => 'on',
                ),
                array(
                    'name'          => 'wpb_wps_scroll_per_page',
                    'label'         => __( 'Slider scroll per page', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc' => __( 'Scroll per page not per item. This affect next/prev buttons and mouse/touch dragging.', 'wpb-woocommerce-product-slider' ),
                    'type'          => 'checkbox',
                    'default'       => 'off',
                ),
                array(
                    'name'          => 'wpb_wps_slider_speed',
                    'label'         => __( 'Slider Speed', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc' => __( 'Slide speed in milliseconds. Default 500 milliseconds.', 'wpb-woocommerce-product-slider' ),
                    'type'          => 'number',
                    'default'       => 500,
                ),
                array(
                    'name'          => 'wpb_wps_slider_pagination_speed',
                    'label'         => __( 'Slider Pagination Speed', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc' => __( 'Pagination speed in milliseconds. Default 1000 milliseconds.', 'wpb-woocommerce-product-slider' ),
                    'type'          => 'number',
                    'default'       => 1000,
                ),
            ),

            'wpb_wps_advance_settings' => array(
                array(
                    'name'     => 'wpb_wps_button_x_class',
                    'label'    => __( 'Add to cart button extra class.', 'wpb-woocommerce-product-slider' ),
                    'desc'     => __( 'You can extra CSS class to add to cart button, to match the style to your theme. Space separated for multiple classes.', 'wpb-woocommerce-product-slider' ),
                    'type'     => 'text'
                ),
                array(
                    'name'          => 'wpb_wps_edit_shortcode_link',
                    'label'         => __( 'Edit Shortcode Link', 'wpb-woocommerce-product-slider' ),
                    'checkbox_desc' => __( 'Show edit shortcode link  bellow the slider. Default Yes.', 'wpb-woocommerce-product-slider' ),
                    'type'          => 'checkbox',
                    'default'       => 'on',
                ),
            ),
        );
		return $settings_fields;
    }
	
	// warping the settings
    function wpb_plugin_page() {
        echo '<div class="wrap">';
			$this->settings_api->show_navigation();
			$this->settings_api->show_forms();
		echo '</div>';
		
		echo '<div class="wrap"><h4>Read the documentation <a href="https://wpbean.com/wpb-woocommerce-product-slider-documentation/" target="_blank">Here</a> & Watch the Video tutorial <a href="http://youtu.be/HYJpcCwqvhA" target="_blank">Here</a></h4></div>';
    }

    /**
     * Get all the pages
     *
     * @return array page names with key value pairs
     */
    function get_pages() {
        $pages = get_pages();
        $pages_options = array();
        if ( $pages ) {
            foreach ($pages as $page) {
                $pages_options[$page->ID] = $page->post_title;
            }
        }
        return $pages_options;
    }
}
endif;

$settings = new WPB_wps_main_Settings();