<?php class WP_Widget_onliner_banner extends WP_Widget {
	/**
	 * Sets up a new Text widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 */
	public function __construct() {
		$widget_ops = array(
			'classname' => 'widget_onliner_banner',
			'description' => 'ابزارکی برای درج بنر.',
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'onlinerـbanner', 'درج بنر' , $widget_ops );
	}
	/**
	 * Outputs the content for the current Text widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Text widget instance.
	 */
	public function widget( $args, $instance ) {
		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_onliner_banner', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$widget_text = ! empty( $instance['text'] ) ? $instance['text'] : '';
		/**
		 * Filters the content of the Text widget.
		 *
		 * @since 2.3.0
		 * @since 4.4.0 Added the `$this` parameter.
		 *
		 * @param string         $widget_text The widget content.
		 * @param array          $instance    Array of settings for the current widget.
		 * @param WP_Widget_Text $this        Current Text widget instance.
		 */
		$text = apply_filters( 'widget_onliner_banner', $widget_text, $instance, $this );
		?>
			<div class="onliner_banner">
				<a title="<?php echo $instance['title']; ?>" href="<?php echo $instance['link']; ?>" rel=”<?php echo $instance['follow']; ?>”>
				<img alt="<?php echo $instance['title']; ?>" src="<?php echo $widget_text; ?>">
				</a>
			</div>
		<?php
	}
	/**
	 * Handles updating settings for the current Text widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Settings to save or bool false to cancel saving.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['text'] = wp_kses_post( $new_instance['text'] );
		$instance['link'] = wp_kses_post( $new_instance['link'] );
		$instance['follow'] = wp_kses_post( $new_instance['follow'] );
		return $instance;
	}
	/**
	 * Outputs the Text widget settings form.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '' ) );
		$title = sanitize_text_field( $instance['title'] );
		$text  = sanitize_text_field( $instance['text'] );
		$link  = sanitize_text_field( $instance['link'] );
		$follow= sanitize_text_field( $instance['follow'] );
		$_cfollow   = '';
		$_nocfollow = '';
		if($follow == 'follow'){
			$_cfollow = 'checked';
		}
		elseif($follow == 'nofollow')
		{
			$_nocfollow = 'checked';
		}
		else
		{
			$_cfollow = 'checked';
		}
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'text' ); ?>"><?php _e( 'image:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>" type="text" value="<?php echo esc_attr($text); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'link' ); ?>"><?php _e( 'link:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('link'); ?>" name="<?php echo $this->get_field_name('link'); ?>" type="text" value="<?php echo esc_attr($link); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'follow' ); ?>"><?php _e( 'follow:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('follow'); ?>" name="<?php echo $this->get_field_name('follow'); ?>" type="radio" value="follow" <?php echo $_cfollow ?> />
			<input class="widefat" id="<?php echo $this->get_field_id('follow'); ?>" name="<?php echo $this->get_field_name('follow'); ?>" type="radio" value="nofollow" <?php echo $_nocfollow ?> />
		</p>
		<?php
	}
}
// Register and load the widget
function wpb_load_widget() {
register_widget( 'WP_Widget_onliner_banner' );
}
add_action( 'widgets_init', 'wpb_load_widget' );
?>